@@ -3,7 +3,7 @@
 /**
  * @todo    we must handle the case if sql.php is called directly with a query
  *          that returns 0 rows - to prevent cyclic redirects or includes
- * @package phpMyAdmin
+ * @package PhpMyAdmin
  */
 
 /**
@@ -14,8 +14,27 @@ require_once './libraries/Table.class.php';
 require_once './libraries/check_user_privileges.lib.php';
 require_once './libraries/bookmark.lib.php';
 
-$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.custom.js';
-$GLOBALS['js_include'][] = 'pMap.js';
+$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.16.custom.js';
+$GLOBALS['js_include'][] = 'jquery/timepicker.js';
+$GLOBALS['js_include'][] = 'tbl_change.js';
+// the next one needed because sql.php may do a "goto" to tbl_structure.php
+$GLOBALS['js_include'][] = 'tbl_structure.js';
+$GLOBALS['js_include'][] = 'gis_data_editor.js';
+$GLOBALS['js_include'][] = 'codemirror/lib/codemirror.js';
+$GLOBALS['js_include'][] = 'codemirror/mode/mysql/mysql.js';
+
+
+
+if (isset($_SESSION['profiling'])) {
+    $GLOBALS['js_include'][] = 'highcharts/highcharts.js';
+    /* Files required for chart exporting */
+    $GLOBALS['js_include'][] = 'highcharts/exporting.js';
+    /* < IE 9 doesn't support canvas natively */
+    if (PMA_USR_BROWSER_AGENT == 'IE' && PMA_USR_BROWSER_VER < 9) {
+        $GLOBALS['js_include'][] = 'canvg/flashcanvas.js';
+    }
+    $GLOBALS['js_include'][] = 'canvg/canvg.js';
+}
 
 /**
  * Defines the url to return to in case of error in a sql statement
@@ -33,8 +52,8 @@ if (! empty($goto)) {
     $is_gotofile  = true;
 } // end if
 
-if (!isset($err_url)) {
-    $err_url = (!empty($back) ? $back : $goto)
+if (! isset($err_url)) {
+    $err_url = (! empty($back) ? $back : $goto)
              . '?' . PMA_generate_common_url($db)
              . ((strpos(' ' . $goto, 'db_') != 1 && strlen($table)) ? '&amp;table=' . urlencode($table) : '');
 } // end if
@@ -50,7 +69,7 @@ if (isset($fields['dbase'])) {
 }
 
 /**
- * During inline edit, if we have a relational field, show the dropdown for it
+ * During grid edit, if we have a relational field, show the dropdown for it
  *
  * Logic taken from libraries/display_tbl_lib.php
  *
@@ -58,7 +77,7 @@ if (isset($fields['dbase'])) {
  * better place either.
  */
 if (isset($_REQUEST['get_relational_values']) && $_REQUEST['get_relational_values'] == true) {
-    require_once 'libraries/relation.lib.php';
+    include_once 'libraries/relation.lib.php';
 
     $column = $_REQUEST['column'];
     $foreigners = PMA_getForeigners($db, $table, $column);
@@ -68,8 +87,11 @@ if (isset($_REQUEST['get_relational_values']) && $_REQUEST['get_relational_value
     $foreignData = PMA_getForeignData($foreigners, $column, false, '', '');
 
     if ($_SESSION['tmp_user_values']['relational_display'] == 'D'
-        && (isset($display_field) && strlen($display_field)
-        && (isset($_REQUEST['relation_key_or_display_column']) && $_REQUEST['relation_key_or_display_column']))) {
+        && isset($display_field)
+        && strlen($display_field)
+        && isset($_REQUEST['relation_key_or_display_column'])
+        && $_REQUEST['relation_key_or_display_column']
+    ) {
             $curr_value = $_REQUEST['relation_key_or_display_column'];
     } else {
         $curr_value = $_REQUEST['curr_value'];
@@ -85,23 +107,22 @@ if (isset($_REQUEST['get_relational_values']) && $_REQUEST['get_relational_value
         $dropdown = '<span class="curr_value">' . htmlspecialchars($_REQUEST['curr_value']) . '</span> <a href="browse_foreigners.php' . PMA_generate_common_url($_url_params) . '"'
                     . ' target="_blank" class="browse_foreign" '
                     .'>' . __('Browse foreign values') . '</a>';
-    }
-    else {
+    } else {
         $dropdown = PMA_foreignDropdown($foreignData['disp_row'], $foreignData['foreign_field'], $foreignData['foreign_display'], $curr_value, $cfg['ForeignKeyMaxLimit']);
         $dropdown = '<select>' . $dropdown . '</select>';
     }
 
     $extra_data['dropdown'] = $dropdown;
-    PMA_ajaxResponse(NULL, true, $extra_data);
+    PMA_ajaxResponse(null, true, $extra_data);
 }
 
 /**
- * Just like above, find possible values for enum fields during inline edit.
+ * Just like above, find possible values for enum fields during grid edit.
  *
  * Logic taken from libraries/display_tbl_lib.php
  */
-if(isset($_REQUEST['get_enum_values']) && $_REQUEST['get_enum_values'] == true) {
-    $field_info_query = 'SHOW FIELDS FROM `' . $db . '`.`' . $table . '` LIKE \'' . $_REQUEST['column'] . '\' ;';
+if (isset($_REQUEST['get_enum_values']) && $_REQUEST['get_enum_values'] == true) {
+    $field_info_query = PMA_DBI_get_columns_sql($db, $table, $_REQUEST['column']);
 
     $field_info_result = PMA_DBI_fetch_result($field_info_query, null, null, null, PMA_DBI_QUERY_STORE);
 
@@ -110,9 +131,9 @@ if(isset($_REQUEST['get_enum_values']) && $_REQUEST['get_enum_values'] == true)
     $values = explode(',', str_replace($search, '', $field_info_result[0]['Type']));
 
     $dropdown = '<option value="">&nbsp;</option>';
-    foreach($values as $value) {
+    foreach ($values as $value) {
         $dropdown .= '<option value="' . htmlspecialchars($value) . '"';
-        if($value == $_REQUEST['curr_value']) {
+        if ($value == $_REQUEST['curr_value']) {
             $dropdown .= ' selected="selected"';
         }
         $dropdown .= '>' . $value . '</option>';
@@ -121,14 +142,14 @@ if(isset($_REQUEST['get_enum_values']) && $_REQUEST['get_enum_values'] == true)
     $dropdown = '<select>' . $dropdown . '</select>';
 
     $extra_data['dropdown'] = $dropdown;
-    PMA_ajaxResponse(NULL, true, $extra_data);
+    PMA_ajaxResponse(null, true, $extra_data);
 }
 
 /**
- * Find possible values for set fields during inline edit.
+ * Find possible values for set fields during grid edit.
  */
-if(isset($_REQUEST['get_set_values']) && $_REQUEST['get_set_values'] == true) {
-    $field_info_query = 'SHOW FIELDS FROM `' . $db . '`.`' . $table . '` LIKE \'' . $_REQUEST['column'] . '\' ;';
+if (isset($_REQUEST['get_set_values']) && $_REQUEST['get_set_values'] == true) {
+    $field_info_query = PMA_DBI_get_columns_sql($db, $table, $_REQUEST['column']);
 
     $field_info_result = PMA_DBI_fetch_result($field_info_query, null, null, null, PMA_DBI_QUERY_STORE);
 
@@ -138,9 +159,9 @@ if(isset($_REQUEST['get_set_values']) && $_REQUEST['get_set_values'] == true) {
     $values = explode(',', str_replace($search, '', $field_info_result[0]['Type']));
 
     $select = '';
-    foreach($values as $value) {
+    foreach ($values as $value) {
         $select .= '<option value="' . htmlspecialchars($value) . '"';
-        if(in_array($value, $selected_values, true)) {
+        if (in_array($value, $selected_values, true)) {
             $select .= ' selected="selected"';
         }
         $select .= '>' . $value . '</option>';
@@ -150,14 +171,48 @@ if(isset($_REQUEST['get_set_values']) && $_REQUEST['get_set_values'] == true) {
     $select = '<select multiple="multiple" size="' . $select_size . '">' . $select . '</select>';
 
     $extra_data['select'] = $select;
-    PMA_ajaxResponse(NULL, true, $extra_data);
+    PMA_ajaxResponse(null, true, $extra_data);
 }
+
+/**
+ * Check ajax request to set the column order
+ */
+if (isset($_REQUEST['set_col_prefs']) && $_REQUEST['set_col_prefs'] == true) {
+    $pmatable = new PMA_Table($table, $db);
+    $retval = false;
+
+    // set column order
+    if (isset($_REQUEST['col_order'])) {
+        $col_order = explode(',', $_REQUEST['col_order']);
+        $retval = $pmatable->setUiProp(PMA_Table::PROP_COLUMN_ORDER, $col_order, $_REQUEST['table_create_time']);
+        if (gettype($retval) != 'boolean') {
+            PMA_ajaxResponse($retval->getString(), false);
+        }
+    }
+
+    // set column visibility
+    if ($retval === true && isset($_REQUEST['col_visib'])) {
+        $col_visib = explode(',', $_REQUEST['col_visib']);
+        $retval = $pmatable->setUiProp(PMA_Table::PROP_COLUMN_VISIB, $col_visib, $_REQUEST['table_create_time']);
+        if (gettype($retval) != 'boolean') {
+            PMA_ajaxResponse($retval->getString(), false);
+        }
+    }
+
+    PMA_ajaxResponse(null, ($retval == true));
+}
+
 // Default to browse if no query set and we have table
 // (needed for browsing from DefaultTabTable)
 if (empty($sql_query) && strlen($table) && strlen($db)) {
-    require_once './libraries/bookmark.lib.php';
-    $book_sql_query = PMA_Bookmark_get($db, '\'' . PMA_sqlAddslashes($table) . '\'',
-        'label', FALSE, TRUE);
+    include_once './libraries/bookmark.lib.php';
+    $book_sql_query = PMA_Bookmark_get(
+        $db,
+        '\'' . PMA_sqlAddSlashes($table) . '\'',
+        'label',
+        false,
+        true
+    );
 
     if (! empty($book_sql_query)) {
         $GLOBALS['using_bookmark_message'] = PMA_message::notice(__('Using bookmark "%s" as default browse query.'));
@@ -177,8 +232,10 @@ if (empty($sql_query) && strlen($table) && strlen($db)) {
 }
 
 // instead of doing the test twice
-$is_drop_database = preg_match('/DROP[[:space:]]+(DATABASE|SCHEMA)[[:space:]]+/i',
-    $sql_query);
+$is_drop_database = preg_match(
+    '/DROP[[:space:]]+(DATABASE|SCHEMA)[[:space:]]+/i',
+    $sql_query
+);
 
 /**
  * Check rights in case of DROP DATABASE
@@ -187,11 +244,12 @@ $is_drop_database = preg_match('/DROP[[:space:]]+(DATABASE|SCHEMA)[[:space:]]+/i
  * but since a malicious user may pass this variable by url/form, we don't take
  * into account this case.
  */
-if (!defined('PMA_CHK_DROP')
- && !$cfg['AllowUserDropDatabase']
- && $is_drop_database
- && !$is_superuser) {
-    require_once './libraries/header.inc.php';
+if (! defined('PMA_CHK_DROP')
+    && ! $cfg['AllowUserDropDatabase']
+    && $is_drop_database
+    && ! $is_superuser
+) {
+    include_once './libraries/header.inc.php';
     PMA_mysqlDie(__('"DROP DATABASE" statements are disabled.'), '', '', $err_url);
 } // end if
 
@@ -236,7 +294,7 @@ if ($goto == 'sql.php') {
  * Go back to further page if table should not be dropped
  */
 if (isset($btnDrop) && $btnDrop == __('No')) {
-    if (!empty($back)) {
+    if (! empty($back)) {
         $goto = $back;
     }
     if ($is_gotofile) {
@@ -244,7 +302,7 @@ if (isset($btnDrop) && $btnDrop == __('No')) {
             $table = '';
         }
         $active_page = $goto;
-        require './' . PMA_securePath($goto);
+        include './' . PMA_securePath($goto);
     } else {
         PMA_sendHeaderLocation($cfg['PmaAbsoluteUri'] . str_replace('&amp;', '&', $goto));
     }
@@ -261,11 +319,14 @@ if (isset($btnDrop) && $btnDrop == __('No')) {
  *
  * Also bypassed if only showing php code.or validating a SQL query
  */
-if (! $cfg['Confirm'] || isset($_REQUEST['is_js_confirmed']) || isset($btnDrop)
- // if we are coming from a "Create PHP code" or a "Without PHP Code"
- // dialog, we won't execute the query anyway, so don't confirm
- || isset($GLOBALS['show_as_php'])
- || !empty($GLOBALS['validatequery'])) {
+if (! $cfg['Confirm']
+    || isset($_REQUEST['is_js_confirmed'])
+    || isset($btnDrop)
+    // if we are coming from a "Create PHP code" or a "Without PHP Code"
+    // dialog, we won't execute the query anyway, so don't confirm
+    || isset($GLOBALS['show_as_php'])
+    || ! empty($GLOBALS['validatequery'])
+) {
     $do_confirm = false;
 } else {
     $do_confirm = isset($analyzed_sql[0]['queryflags']['need_confirm']);
@@ -273,7 +334,7 @@ if (! $cfg['Confirm'] || isset($_REQUEST['is_js_confirmed']) || isset($btnDrop)
 
 if ($do_confirm) {
     $stripped_sql_query = $sql_query;
-    require_once './libraries/header.inc.php';
+    include_once './libraries/header.inc.php';
     if ($is_drop_database) {
         echo '<h1 class="error">' . __('You are about to DESTROY a complete database!') . '</h1>';
     }
@@ -304,7 +365,7 @@ if ($do_confirm) {
     /**
      * Displays the footer and exit
      */
-    require './libraries/footer.inc.php';
+    include './libraries/footer.inc.php';
 } // end if $do_confirm
 
 
@@ -315,7 +376,8 @@ if ($do_confirm) {
  */
 
 if (empty($reload)
-    && preg_match('/^(CREATE|ALTER|DROP)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i', $sql_query)) {
+    && preg_match('/^(CREATE|ALTER|DROP)\s+(VIEW|TABLE|DATABASE|SCHEMA)\s+/i', $sql_query)
+) {
     $reload = 1;
 }
 
@@ -333,8 +395,8 @@ if (empty($reload)
 $is_explain = $is_count = $is_export = $is_delete = $is_insert = $is_affected = $is_show = $is_maint = $is_analyse = $is_group = $is_func = $is_replace = false;
 if ($is_select) { // see line 141
     $is_group = preg_match('@(GROUP[[:space:]]+BY|HAVING|SELECT[[:space:]]+DISTINCT)[[:space:]]+@i', $sql_query);
-    $is_func =  !$is_group && (preg_match('@[[:space:]]+(SUM|AVG|STD|STDDEV|MIN|MAX|BIT_OR|BIT_AND)\s*\(@i', $sql_query));
-    $is_count = !$is_group && (preg_match('@^SELECT[[:space:]]+COUNT\((.*\.+)?.*\)@i', $sql_query));
+    $is_func =  ! $is_group && (preg_match('@[[:space:]]+(SUM|AVG|STD|STDDEV|MIN|MAX|BIT_OR|BIT_AND)\s*\(@i', $sql_query));
+    $is_count = ! $is_group && (preg_match('@^SELECT[[:space:]]+COUNT\((.*\.+)?.*\)@i', $sql_query));
     $is_export   = (preg_match('@[[:space:]]+INTO[[:space:]]+OUTFILE[[:space:]]+@i', $sql_query));
     $is_analyse  = (preg_match('@[[:space:]]+PROCEDURE[[:space:]]+ANALYSE@i', $sql_query));
 } elseif (preg_match('@^EXPLAIN[[:space:]]+@i', $sql_query)) {
@@ -356,16 +418,47 @@ if ($is_select) { // see line 141
     $is_maint    = true;
 }
 
-// Do append a "LIMIT" clause?
-if ((! $cfg['ShowAll'] || $_SESSION['tmp_user_values']['max_rows'] != 'all')
- && ! ($is_count || $is_export || $is_func || $is_analyse)
- && isset($analyzed_sql[0]['queryflags']['select_from'])
- && ! isset($analyzed_sql[0]['queryflags']['offset'])
- && empty($analyzed_sql[0]['limit_clause'])
- ) {
-    $sql_limit_to_append = ' LIMIT ' . $_SESSION['tmp_user_values']['pos'] . ', ' . $_SESSION['tmp_user_values']['max_rows'] . " ";
+// assign default full_sql_query
+$full_sql_query = $sql_query;
 
-    $full_sql_query  = $analyzed_sql[0]['section_before_limit'] . "\n" . $sql_limit_to_append . $analyzed_sql[0]['section_after_limit'];
+// Handle remembered sorting order, only for single table query
+if ($GLOBALS['cfg']['RememberSorting']
+    && ! ($is_count || $is_export || $is_func || $is_analyse)
+    && count($analyzed_sql[0]['select_expr']) == 0
+    && isset($analyzed_sql[0]['queryflags']['select_from'])
+    && count($analyzed_sql[0]['table_ref']) == 1
+) {
+    $pmatable = new PMA_Table($table, $db);
+    if (empty($analyzed_sql[0]['order_by_clause'])) {
+        $sorted_col = $pmatable->getUiProp(PMA_Table::PROP_SORTED_COLUMN);
+        if ($sorted_col) {
+            // retrieve the remembered sorting order for current table
+            $sql_order_to_append = ' ORDER BY ' . $sorted_col . ' ';
+            $full_sql_query = $analyzed_sql[0]['section_before_limit'] . $sql_order_to_append
+                . $analyzed_sql[0]['section_after_limit'];
+
+            // update the $analyzed_sql
+            $analyzed_sql[0]['section_before_limit'] .= $sql_order_to_append;
+            $analyzed_sql[0]['order_by_clause'] = $sorted_col;
+        }
+    } else {
+        // store the remembered table into session
+        $pmatable->setUiProp(PMA_Table::PROP_SORTED_COLUMN, $analyzed_sql[0]['order_by_clause']);
+    }
+}
+
+// Do append a "LIMIT" clause?
+if (($_SESSION['tmp_user_values']['max_rows'] != 'all')
+    && ! ($is_count || $is_export || $is_func || $is_analyse)
+    && isset($analyzed_sql[0]['queryflags']['select_from'])
+    && ! isset($analyzed_sql[0]['queryflags']['offset'])
+    && empty($analyzed_sql[0]['limit_clause'])
+) {
+    $sql_limit_to_append = ' LIMIT ' . $_SESSION['tmp_user_values']['pos']
+        . ', ' . $_SESSION['tmp_user_values']['max_rows'] . " ";
+
+    $full_sql_query  = $analyzed_sql[0]['section_before_limit'] . "\n"
+        . $sql_limit_to_append . $analyzed_sql[0]['section_after_limit'];
     /**
      * @todo pretty printing of this modified query
      */
@@ -374,15 +467,16 @@ if ((! $cfg['ShowAll'] || $_SESSION['tmp_user_values']['max_rows'] != 'all')
         // a section_after_limit, we now have to analyze $display_query
         // to display it correctly
 
-        if (!empty($analyzed_sql[0]['section_after_limit']) && trim($analyzed_sql[0]['section_after_limit']) != ';') {
+        if (! empty($analyzed_sql[0]['section_after_limit'])
+            && trim($analyzed_sql[0]['section_after_limit']) != ';'
+        ) {
             $analyzed_display_query = PMA_SQP_analyze(PMA_SQP_parse($display_query));
-            $display_query  = $analyzed_display_query[0]['section_before_limit'] . "\n" . $sql_limit_to_append . $analyzed_display_query[0]['section_after_limit'];
+            $display_query  = $analyzed_display_query[0]['section_before_limit']
+                . "\n" . $sql_limit_to_append . $analyzed_display_query[0]['section_after_limit'];
         }
     }
 
-} else {
-    $full_sql_query      = $sql_query;
-} // end if...else
+}
 
 if (strlen($db)) {
     PMA_DBI_select_db($db);
@@ -391,9 +485,10 @@ if (strlen($db)) {
 //  E x e c u t e    t h e    q u e r y
 
 // Only if we didn't ask to see the php code (mikebeck)
-if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
+if (isset($GLOBALS['show_as_php']) || ! empty($GLOBALS['validatequery'])) {
     unset($result);
     $num_rows = 0;
+    $unlim_num_rows = 0;
 } else {
     if (isset($_SESSION['profiling']) && PMA_profilingSupported()) {
         PMA_DBI_query('SET PROFILING=1;');
@@ -404,6 +499,15 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
 
     $result   = @PMA_DBI_try_query($full_sql_query, null, PMA_DBI_QUERY_STORE);
 
+    // If a stored procedure was called, there may be more results that are
+    // queued up and waiting to be flushed from the buffer. So let's do that.
+    while (true) {
+        if (! PMA_DBI_more_results()) {
+            break;
+        }
+        PMA_DBI_next_result();
+    }
+
     $querytime_after = array_sum(explode(' ', microtime()));
 
     $GLOBALS['querytime'] = $querytime_after - $querytime_before;
@@ -417,14 +521,14 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
             $active_page = $goto;
             $message = PMA_Message::rawError($error);
 
-            if( $GLOBALS['is_ajax_request'] == true) {
+            if ($GLOBALS['is_ajax_request'] == true) {
                 PMA_ajaxResponse($message, false);
             }
 
             /**
              * Go to target path.
              */
-            require './' . PMA_securePath($goto);
+            include './' . PMA_securePath($goto);
         } else {
             $full_err_url = (preg_match('@^(db|tbl)_@', $err_url))
                           ? $err_url . '&amp;show_query=1&amp;sql_query=' . urlencode($sql_query)
@@ -439,9 +543,9 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
     // (This must be done immediately after the query because
     // mysql_affected_rows() reports about the last query done)
 
-    if (!$is_affected) {
+    if (! $is_affected) {
         $num_rows = ($result) ? @PMA_DBI_num_rows($result) : 0;
-    } elseif (!isset($num_rows)) {
+    } elseif (! isset($num_rows)) {
         $num_rows = @PMA_DBI_affected_rows();
     }
 
@@ -467,7 +571,8 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
 
     // tmpfile remove after convert encoding appended by Y.Kawada
     if (function_exists('PMA_kanji_file_conv')
-        && (isset($textfile) && file_exists($textfile))) {
+        && (isset($textfile) && file_exists($textfile))
+    ) {
         unlink($textfile);
     }
 
@@ -491,12 +596,12 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
         // However, do not count again if we did it previously
         // due to $find_real_end == true
 
-        if (!$is_group
-         && !isset($analyzed_sql[0]['queryflags']['union'])
-         && !isset($analyzed_sql[0]['table_ref'][1]['table_name'])
-         && (empty($analyzed_sql[0]['where_clause'])
-           || $analyzed_sql[0]['where_clause'] == '1 ')
-         && !isset($find_real_end)
+        if (! $is_group
+            && ! isset($analyzed_sql[0]['queryflags']['union'])
+            && ! isset($analyzed_sql[0]['queryflags']['distinct'])
+            && ! isset($analyzed_sql[0]['table_ref'][1]['table_name'])
+            && (empty($analyzed_sql[0]['where_clause']) || $analyzed_sql[0]['where_clause'] == '1 ')
+            && ! isset($find_real_end)
         ) {
 
             // "j u s t   b r o w s i n g"
@@ -515,7 +620,7 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
             $count_query = PMA_SQP_formatHtml($parsed_sql, 'query_only', 0, $analyzed_sql[0]['position_of_first_select'] + 1);
             $count_query .= ' SQL_CALC_FOUND_ROWS ';
             // add everything that was after the first SELECT
-            $count_query .= PMA_SQP_formatHtml($parsed_sql, 'query_only', $analyzed_sql[0]['position_of_first_select']+1);
+            $count_query .= PMA_SQP_formatHtml($parsed_sql, 'query_only', $analyzed_sql[0]['position_of_first_select'] + 1);
             // ensure there is no semicolon at the end of the
             // count query because we'll probably add
             // a LIMIT 1 clause after it
@@ -526,7 +631,7 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
             // long delays. Returned count will be complete anyway.
             // (but a LIMIT would disrupt results in an UNION)
 
-            if (!isset($analyzed_sql[0]['queryflags']['union'])) {
+            if (! isset($analyzed_sql[0]['queryflags']['union'])) {
                 $count_query .= ' LIMIT 1';
             }
 
@@ -560,7 +665,7 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
         /**
          * Cleanup relations.
          */
-        require_once './libraries/relation_cleanup.lib.php';
+        include_once './libraries/relation_cleanup.lib.php';
 
         if (strlen($table) && strlen($db)) {
             PMA_relationsCleanupTable($db, $table);
@@ -572,15 +677,16 @@ if (isset($GLOBALS['show_as_php']) || !empty($GLOBALS['validatequery'])) {
     } // end if ($purge)
 
     // If a column gets dropped, do relation magic.
-    if (isset($dropped_column) && strlen($db) && strlen($table) && !empty($dropped_column)) {
-        require_once './libraries/relation_cleanup.lib.php';
+    if (isset($dropped_column) && strlen($db) && strlen($table) && ! empty($dropped_column)) {
+        include_once './libraries/relation_cleanup.lib.php';
         PMA_relationsCleanupColumn($db, $table, $dropped_column);
-
+        // to refresh the list of indexes (Ajax mode)
+        $extra_data['indexes_list'] = PMA_Index::getView($table, $db);
     } // end if column was dropped
 } // end else "didn't ask to see php code"
 
 // No rows returned -> move back to the calling page
-if (0 == $num_rows || $is_affected) {
+if ((0 == $num_rows && 0 == $unlim_num_rows) || $is_affected) {
     if ($is_delete) {
         $message = PMA_Message::deleted_rows($num_rows);
     } elseif ($is_insert) {
@@ -611,14 +717,14 @@ if (0 == $num_rows || $is_affected) {
         // fact that $message_to_show is sent for every case.
         // The $message_to_show containing a success message and sent with
         // the form should not have priority over errors
-    } elseif (!empty($message_to_show) && !$is_select) {
+    } elseif (! empty($message_to_show) && ! $is_select) {
         $message = PMA_Message::rawSuccess(htmlspecialchars($message_to_show));
-    } elseif (!empty($GLOBALS['show_as_php'])) {
+    } elseif (! empty($GLOBALS['show_as_php'])) {
         $message = PMA_Message::success(__('Showing as PHP code'));
     } elseif (isset($GLOBALS['show_as_php'])) {
         /* User disable showing as PHP, query is only displayed */
         $message = PMA_Message::notice(__('Showing SQL query'));
-    } elseif (!empty($GLOBALS['validatequery'])) {
+    } elseif (! empty($GLOBALS['validatequery'])) {
         $message = PMA_Message::notice(__('Validated SQL'));
     } else {
         $message = PMA_Message::success(__('MySQL returned an empty result set (i.e. zero rows).'));
@@ -632,120 +738,7 @@ if (0 == $num_rows || $is_affected) {
         $message->addMessage(')');
     }
 
-    if( $GLOBALS['is_ajax_request'] == true) {
-
-        /**
-         * If we are in inline editing, we need to process the relational and
-         * transformed fields, if they were edited. After that, output the correct
-         * link/transformed value and exit
-         *
-         * Logic taken from libraries/display_tbl.lib.php
-         */
-
-        if(isset($_REQUEST['rel_fields_list']) && $_REQUEST['rel_fields_list'] != '') {
-            //handle relations work here for updated row.
-            require_once './libraries/relation.lib.php';
-
-            $map = PMA_getForeigners($db, $table, '', 'both');
-
-            $rel_fields = array();
-            parse_str($_REQUEST['rel_fields_list'], $rel_fields);
-
-            foreach( $rel_fields as $rel_field => $rel_field_value) {
-
-                $where_comparison = "='" . $rel_field_value . "'";
-                $display_field = PMA_getDisplayField($map[$rel_field]['foreign_db'], $map[$rel_field]['foreign_table']);
-
-                // Field to display from the foreign table?
-                if (isset($display_field) && strlen($display_field)) {
-                    $dispsql     = 'SELECT ' . PMA_backquote($display_field)
-                        . ' FROM ' . PMA_backquote($map[$rel_field]['foreign_db'])
-                        . '.' . PMA_backquote($map[$rel_field]['foreign_table'])
-                        . ' WHERE ' . PMA_backquote($map[$rel_field]['foreign_field'])
-                        . $where_comparison;
-                    $dispresult  = PMA_DBI_try_query($dispsql, null, PMA_DBI_QUERY_STORE);
-                    if ($dispresult && PMA_DBI_num_rows($dispresult) > 0) {
-                        list($dispval) = PMA_DBI_fetch_row($dispresult, 0);
-                    } else {
-                        //$dispval = __('Link not found');
-                    }
-                    @PMA_DBI_free_result($dispresult);
-                } else {
-                    $dispval     = '';
-                } // end if... else...
-
-                if ('K' == $_SESSION['tmp_user_values']['relational_display']) {
-                    // user chose "relational key" in the display options, so
-                    // the title contains the display field
-                    $title = (! empty($dispval))? ' title="' . htmlspecialchars($dispval) . '"' : '';
-                } else {
-                    $title = ' title="' . htmlspecialchars($rel_field_value) . '"';
-                }
-
-                $_url_params = array(
-                    'db'    => $map[$rel_field]['foreign_db'],
-                    'table' => $map[$rel_field]['foreign_table'],
-                    'pos'   => '0',
-                    'sql_query' => 'SELECT * FROM '
-                                        . PMA_backquote($map[$rel_field]['foreign_db']) . '.' . PMA_backquote($map[$rel_field]['foreign_table'])
-                                        . ' WHERE ' . PMA_backquote($map[$rel_field]['foreign_field'])
-                                        . $where_comparison
-                );
-                $output = '<a href="sql.php' . PMA_generate_common_url($_url_params) . '"' . $title . '>';
-
-                if ('D' == $_SESSION['tmp_user_values']['relational_display']) {
-                    // user chose "relational display field" in the
-                    // display options, so show display field in the cell
-                    $output .= (!empty($dispval)) ? htmlspecialchars($dispval) : '';
-                } else {
-                    // otherwise display data in the cell
-                    $output .= htmlspecialchars($rel_field_value);
-                }
-                $output .= '</a>';
-                $extra_data['relations'][$rel_field] = $output;
-            }
-        }
-
-        if(isset($_REQUEST['do_transformations']) && $_REQUEST['do_transformations'] == true ) {
-            require_once './libraries/transformations.lib.php';
-            //if some posted fields need to be transformed, generate them here.
-            $mime_map = PMA_getMIME($db, $table);
-
-            if ($mime_map === FALSE) {
-                $mime_map = array();
-            }
-
-            $edited_values = array();
-            parse_str($_REQUEST['transform_fields_list'], $edited_values);
-
-            foreach($mime_map as $transformation) {
-                $include_file = $transformation['transformation'];
-                $column_name = $transformation['column_name'];
-                $column_data = $edited_values[$column_name];
-
-                $_url_params = array(
-                    'db'            => $db,
-                    'table'         => $table,
-                    'where_clause'  => $_REQUEST['where_clause'],
-                    'transform_key' => $column_name,
-                );
-
-                if (file_exists('./libraries/transformations/' . $include_file)) {
-                    $transformfunction_name = str_replace('.inc.php', '', $transformation['transformation']);
-
-                    require_once './libraries/transformations/' . $include_file;
-
-                    if (function_exists('PMA_transformation_' . $transformfunction_name)) {
-                        $transform_function = 'PMA_transformation_' . $transformfunction_name;
-                        $transform_options  = PMA_transformation_getOptions((isset($transformation['transformation_options']) ? $transformation['transformation_options'] : ''));
-                        $transform_options['wrapper_link'] = PMA_generate_common_url($_url_params);
-                    }
-                }
-
-                $extra_data['transformations'][$column_name] = $transform_function($column_data, $transform_options);
-            }
-        }
-
+    if ($GLOBALS['is_ajax_request'] == true) {
         if ($cfg['ShowSQL']) {
             $extra_data['sql_query'] = PMA_showMessage($message, $GLOBALS['sql_query'], 'success');
         }
@@ -760,7 +753,7 @@ if (0 == $num_rows || $is_affected) {
         $goto = PMA_securePath($goto);
         // Checks for a valid target script
         $is_db = $is_table = false;
-        if (isset($_REQUEST['purge'])) {
+        if (isset($_REQUEST['purge']) && $_REQUEST['purge'] == '1') {
             $table = '';
             unset($url_params['table']);
         }
@@ -780,29 +773,56 @@ if (0 == $num_rows || $is_affected) {
         }
         // Loads to target script
         if ($goto != 'main.php') {
-            require_once './libraries/header.inc.php';
+            include_once './libraries/header.inc.php';
         }
         $active_page = $goto;
-        require './' . $goto;
+        include './' . $goto;
     } else {
         // avoid a redirect loop when last record was deleted
         if (0 == $num_rows && 'sql.php' == $cfg['DefaultTabTable']) {
-            $goto = str_replace('sql.php','tbl_structure.php',$goto);
+            $goto = str_replace('sql.php', 'tbl_structure.php', $goto);
         }
         PMA_sendHeaderLocation($cfg['PmaAbsoluteUri'] . str_replace('&amp;', '&', $goto) . '&message=' . urlencode($message));
     } // end else
     exit();
-} // end no rows returned
-
-// At least one row is returned -> displays a table with results
-else {
+// end no rows returned
+} else {
+    // At least one row is returned -> displays a table with results
     //If we are retrieving the full value of a truncated field or the original
     // value of a transformed field, show it here and exit
-    if( $GLOBALS['inline_edit'] == true && $GLOBALS['cfg']['AjaxEnable']) {
+    if ($GLOBALS['grid_edit'] == true && $GLOBALS['cfg']['AjaxEnable']) {
         $row = PMA_DBI_fetch_row($result);
         $extra_data = array();
         $extra_data['value'] = $row[0];
-        PMA_ajaxResponse(NULL, true, $extra_data);
+        PMA_ajaxResponse(null, true, $extra_data);
+    }
+
+    if (isset($_REQUEST['ajax_request']) && isset($_REQUEST['table_maintenance'])) {
+        $GLOBALS['js_include'][] = 'functions.js';
+        $GLOBALS['js_include'][] = 'makegrid.js';
+        $GLOBALS['js_include'][] = 'sql.js';
+
+        // Gets the list of fields properties
+        if (isset($result) && $result) {
+            $fields_meta = PMA_DBI_get_fields_meta($result);
+            $fields_cnt  = count($fields_meta);
+        }
+
+        if (empty($disp_mode)) {
+            // see the "PMA_setDisplayMode()" function in
+            // libraries/display_tbl.lib.php
+            $disp_mode = 'urdr111101';
+        }
+
+        // hide edit and delete links for information_schema
+        if (PMA_is_system_schema($db)) {
+            $disp_mode = 'nnnn110111';
+        }
+
+        $message = PMA_Message::success($message);
+        echo PMA_showMessage($message, $GLOBALS['sql_query'], 'success');
+        PMA_displayTable($result, $disp_mode, $analyzed_sql);
+        exit();
     }
 
     // Displays the headers
@@ -810,30 +830,30 @@ else {
         unset($show_query);
     }
     if (isset($printview) && $printview == '1') {
-        require_once './libraries/header_printview.inc.php';
+        include_once './libraries/header_printview.inc.php';
     } else {
 
         $GLOBALS['js_include'][] = 'functions.js';
+        $GLOBALS['js_include'][] = 'makegrid.js';
         $GLOBALS['js_include'][] = 'sql.js';
 
         unset($message);
 
-        if( ! $GLOBALS['is_ajax_request'] || ! $GLOBALS['cfg']['AjaxEnable']) {
+        if (! $GLOBALS['is_ajax_request'] || ! $GLOBALS['cfg']['AjaxEnable']) {
             if (strlen($table)) {
-                require './libraries/tbl_common.php';
+                include './libraries/tbl_common.php';
                 $url_query .= '&amp;goto=tbl_sql.php&amp;back=tbl_sql.php';
-                require './libraries/tbl_info.inc.php';
-                require './libraries/tbl_links.inc.php';
+                include './libraries/tbl_info.inc.php';
+                include './libraries/tbl_links.inc.php';
             } elseif (strlen($db)) {
-                require './libraries/db_common.inc.php';
-                require './libraries/db_info.inc.php';
+                include './libraries/db_common.inc.php';
+                include './libraries/db_info.inc.php';
             } else {
-                require './libraries/server_common.inc.php';
-                require './libraries/server_links.inc.php';
+                include './libraries/server_common.inc.php';
+                include './libraries/server_links.inc.php';
             }
-        }
-        else {
-            require_once './libraries/header.inc.php';
+        } else {
+            include_once './libraries/header.inc.php';
             //we don't need to buffer the output in PMA_showMessage here.
             //set a global variable and check against it in the function
             $GLOBALS['buffer_message'] = false;
@@ -850,7 +870,7 @@ else {
         $fields_cnt  = count($fields_meta);
     }
 
-    if( ! $GLOBALS['is_ajax_request']) {
+    if (! $GLOBALS['is_ajax_request']) {
         //begin the sqlqueryresults div here. container div
         echo '<div id="sqlqueryresults"';
         if ($GLOBALS['cfg']['AjaxEnable']) {
@@ -865,7 +885,38 @@ else {
     }
 
     if (isset($profiling_results)) {
-        PMA_profilingResults($profiling_results, true);
+        // pma_token/url_query needed for chart export
+?>
+<script type="text/javascript">
+pma_token = '<?php echo $_SESSION[' PMA_token ']; ?>';
+url_query = '<?php echo isset($url_query)?$url_query:PMA_generate_common_url($db);?>';
+$(document).ready(makeProfilingChart);
+</script>
+<?php
+        echo '<fieldset><legend>' . __('Profiling') . '</legend>' . "\n";
+        echo '<div style="float: left;">';
+        echo '<table>' . "\n";
+        echo ' <tr>' .  "\n";
+        echo '  <th>' . __('Status') . PMA_showMySQLDocu('general-thread-states', 'general-thread-states') .  '</th>' . "\n";
+        echo '  <th>' . __('Time') . '</th>' . "\n";
+        echo ' </tr>' .  "\n";
+
+        $chart_json = Array();
+        foreach ($profiling_results as $one_result) {
+            echo ' <tr>' .  "\n";
+            echo '<td>' . ucwords($one_result['Status']) . '</td>' .  "\n";
+            echo '<td align="right">' . (PMA_formatNumber($one_result['Duration'], 3, 1)) . 's</td>' .  "\n";
+            $chart_json[ucwords($one_result['Status'])] = $one_result['Duration'];
+        }
+
+        echo '</table>' . "\n";
+        echo '</div>';
+        //require_once './libraries/chart.lib.php';
+        echo '<div id="profilingchart" style="display:none;">';
+        //PMA_chart_profiling($profiling_results);
+        echo json_encode($chart_json);
+        echo '</div>';
+        echo '</fieldset>' . "\n";
     }
 
     // Displays the results in a table
@@ -876,7 +927,7 @@ else {
     }
 
     // hide edit and delete links for information_schema
-    if ($db == 'information_schema') {
+    if (PMA_is_system_schema($db)) {
         $disp_mode = 'nnnn110111';
     }
 
@@ -903,7 +954,8 @@ else {
     // Bookmark support if required
     if ($disp_mode[7] == '1'
         && (! empty($cfg['Bookmark']) && empty($id_bookmark))
-        && !empty($sql_query)) {
+        && ! empty($sql_query)
+    ) {
         echo "\n";
 
         $goto = 'sql.php?'
@@ -920,8 +972,7 @@ else {
 <input type="hidden" name="fields[query]" value="<?php echo urlencode(isset($complete_query) ? $complete_query : $sql_query); ?>" />
 <fieldset>
     <legend><?php
-     echo ($cfg['PropertiesIconic'] ? '<img class="icon" src="' . $pmaThemeImage . 'b_bookmark.png" width="16" height="16" alt="' . __('Bookmark this SQL query') . '" />' : '')
-        . __('Bookmark this SQL query');
+    echo PMA_getIcon('b_bookmark.png', __('Bookmark this SQL query'), true);
 ?>
     </legend>
 
@@ -946,22 +997,10 @@ else {
 
     // Do print the page if required
     if (isset($printview) && $printview == '1') {
-        ?>
-<script type="text/javascript">
-//<![CDATA[
-// Do print the page
-window.onload = function()
-{
-    if (typeof(window.print) != 'undefined') {
-        window.print();
-    }
-}
-//]]>
-</script>
-        <?php
+        PMA_printButton();
     } // end print case
 
-    if( $GLOBALS['is_ajax_request'] != true) {
+    if ($GLOBALS['is_ajax_request'] != true) {
         echo '</div>'; // end sqlqueryresults div
     }
 } // end rows returned
@@ -969,7 +1008,7 @@ window.onload = function()
 /**
  * Displays the footer
  */
-if(!isset($_REQUEST['table_maintenance'])) {
-    require './libraries/footer.inc.php';
+if (! isset($_REQUEST['table_maintenance'])) {
+    include './libraries/footer.inc.php';
 }
 ?>
