@@ -2,7 +2,7 @@
 /* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  *
- * @version $Id: tbl_export.php 11061 2008-01-18 18:29:17Z lem9 $
+ * @package PhpMyAdmin
  */
 
 /**
@@ -10,6 +10,8 @@
  */
 require_once './libraries/common.inc.php';
 
+$GLOBALS['js_include'][] = 'export.js';
+
 /**
  * Gets tables informations and displays top links
  */
@@ -19,7 +21,7 @@ require_once './libraries/tbl_info.inc.php';
 
 // Dump of a table
 
-$export_page_title = $strViewDump;
+$export_page_title = __('View dump (schema) of table');
 
 // When we have some query, we need to remove LIMIT from that and possibly
 // generate WHERE clause (if we are asked to export specific rows)
@@ -30,8 +32,8 @@ if (! empty($sql_query)) {
     $analyzed_sql = PMA_SQP_analyze($parsed_sql);
 
     // Need to generate WHERE clause?
-    if (isset($primary_key)) {
-        // Yes => rebuild query from scracts, this doesn't work with nested
+    if (isset($where_clause)) {
+        // Yes => rebuild query from scratch; this doesn't work with nested
         // selects :-(
         $sql_query = 'SELECT ';
 
@@ -47,12 +49,12 @@ if (! empty($sql_query)) {
 
         $wheres = array();
 
-        if (isset($primary_key) && is_array($primary_key)
-         && count($primary_key) > 0) {
-            $wheres[] = '(' . implode(') OR (',$primary_key) . ')';
+        if (isset($where_clause) && is_array($where_clause)
+         && count($where_clause) > 0) {
+            $wheres[] = '(' . implode(') OR (', $where_clause) . ')';
         }
 
-        if (!empty($analyzed_sql[0]['where_clause']))  {
+        if (!empty($analyzed_sql[0]['where_clause'])) {
             $wheres[] = $analyzed_sql[0]['where_clause'];
         }
 
@@ -88,5 +90,5 @@ require_once './libraries/display_export.lib.php';
 /**
  * Displays the footer
  */
-require_once './libraries/footer.inc.php';
+require './libraries/footer.inc.php';
 ?>
